
# Slot: exacerbates


A relationship between an entity (e.g. a chemical, environmental exposure, or some form of genetic variation) and a condition (a phenotype or disease), where the presence of the entity worsens some or all aspects of the condition.

URI: [biolink:exacerbates](https://w3id.org/biolink/vocab/exacerbates)


## Domain and Range

[BiologicalEntity](BiologicalEntity.md) &#8594;  <sub>0..\*</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [affects](affects.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | RO:0003309 |

